@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,26 +8,26 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
-#Enter data dir
+# Enter data dir
 cd ${data_dir}/bufr
 
-#Define a common label for all the tmp files
+# Define a common label for all the tmp files
 label="bufr_compare_test"
 
-#Create log file
-fLog=${label}".log"
+# Create log file
+fLog=temp.${label}".log"
 rm -f $fLog
 touch $fLog
 
-#Define tmp bufr file
-fBufrTmp=${label}".bufr.tmp"
-fBufrInput1=${label}".bufr.input1"
-fBufrInput2=${label}".bufr.input2"
+# Define tmp bufr file
+fBufrTmp=temp.${label}".bufr"
+fBufrInput1=temp1.in.${label}".bufr"
+fBufrInput2=temp2.in.${label}".bufr"
 
-#Define filter rules file
-fRules=${label}.filter
+# Define filter rules file
+fRules=temp.${label}.filter
 
 #----------------------------------------------------
 # Test: comparing same files
@@ -56,10 +56,10 @@ set -e
 # Test: comparing with and without the -b switch
 #----------------------------------------------------
 f="syno_1.bufr"
-echo "Test: comparing with and witout the -b switch" >> $fLog
+echo "Test: comparing with and without the -b switch" >> $fLog
 echo "file: $f" >> $fLog
 
-#Alter a key in the file 
+# Alter a key in the file 
 ${tools_dir}/bufr_set -s dataCategory=2 $f ${fBufrTmp} >> $fLog
 
 set +e
@@ -76,7 +76,7 @@ ${tools_dir}/bufr_compare -b dataCategory $f ${fBufrTmp}>> $fLog
 #----------------------------------------------------
 # Test: comparing with the -r switch
 #----------------------------------------------------
-#Create a bufr file with various message types
+# Create a bufr file with various message types
 #cat syno_multi.bufr temp_101.bufr > $fBufrInput1 
 #cat temp_101.bufr syno_multi.bufr > $fBufrInput2
 
@@ -92,6 +92,7 @@ ${tools_dir}/bufr_compare -b dataCategory $f ${fBufrTmp}>> $fLog
 #----------------------------------------------------
 # Change subCentre and compare
 #----------------------------------------------------
+echo "Test: Change subCentre and compare" >> $fLog
 ${tools_dir}/bufr_set -s bufrHeaderSubCentre=12 aaen_55.bufr $fBufrTmp
 set +e
 ${tools_dir}/bufr_compare aaen_55.bufr $fBufrTmp > $fLog 2>&1
@@ -100,9 +101,23 @@ set -e
 [ $status -eq 1 ]
 fgrep -q "[bufrHeaderSubCentre]: [70] != [12]" $fLog
 
+#----------------------------------------------------
+# First argument of bufr_compare is a directory (error)
+#----------------------------------------------------
+echo "Test: First argument of bufr_compare is a directory (error)" >> $fLog
+temp_dir=tempdir.${label}
+mkdir -p $temp_dir
+set +e
+${tools_dir}/bufr_compare $temp_dir aaen_55.bufr >/dev/null
+status=$?
+set -e
+[ $status -eq 1 ]
+rm -fr $temp_dir
+
 #----------------------------------------------------
 # Second argument of bufr_compare is a directory
 #----------------------------------------------------
+echo "Test: Second argument of bufr_compare is a directory" >> $fLog
 temp_dir=tempdir.${label}
 mkdir -p $temp_dir
 infile=aaen_55.bufr
@@ -113,6 +128,7 @@ rm -fr $temp_dir
 #----------------------------------------------------
 # Compare attributes
 #----------------------------------------------------
+echo "Test: Compare attributes" >> $fLog
 set +e
 ${tools_dir}/bufr_compare amv2_87.bufr amv3_87.bufr > $fLog 2>&1
 status=$?
@@ -124,8 +140,9 @@ grep -q "#1#windSpeed->percentConfidence" $fLog
 grep -q "#1#coldestClusterTemperature->percentConfidence" $fLog
 
 #----------------------------------------------------
-# Header only mode
+# Header-only mode
 #----------------------------------------------------
+echo "Test: Header-only mode" >> $fLog
 f="syno_1.bufr"
 cat > $fRules <<EOF
  set unpack=1;
@@ -141,6 +158,7 @@ ${tools_dir}/bufr_compare -H $f $fBufrTmp
 #----------------------------------------------------
 # Compare two-way (symmetric mode)
 #----------------------------------------------------
+echo "Test: Compare two-way (symmetric mode)" >> $fLog
 f=$ECCODES_SAMPLES_PATH/BUFR3.tmpl
 # Add a local section
 ${tools_dir}/bufr_set -s section2Present=1 $f $fBufrTmp
@@ -156,16 +174,17 @@ set -e
 #----------------------------------------------------
 # ECC-656: using relative comparison (-R) with 'all'
 #----------------------------------------------------
+echo "Test: ECC-656: using relative comparison (-R) with 'all'" >> $fLog
 f='airc_142.bufr'
 echo 'set unpack=1;set airTemperature=228; set height=1.037e+04; set pack=1; write;' |\
     ${tools_dir}/codes_bufr_filter -o $fBufrTmp - $f
 ${tools_dir}/bufr_compare -R airTemperature=0.004,height=0.001 $f $fBufrTmp
 ${tools_dir}/bufr_compare -R all=0.004 $f $fBufrTmp
 
-#----------------------------------------------------
-# ECC-658: apply relative comparison (-R) to all
-# ranks of a given key
-#----------------------------------------------------
+#--------------------------------------------------------------------
+# ECC-658: apply relative comparison (-R) to all ranks of a given key
+#--------------------------------------------------------------------
+echo "Test: ECC-658: apply relative comparison (-R) to all ranks of a given key" >> $fLog
 f='PraticaTemp.bufr'
 ${tools_dir}/codes_bufr_filter -o $fBufrTmp - $f <<EOF
  set unpack=1;
@@ -180,6 +199,69 @@ EOF
 # The relative differences are around 3.5e-5. Suppress all instances
 ${tools_dir}/bufr_compare -R airTemperature=4e-5 $f $fBufrTmp
 
+#--------------------------------------------------------------------
+# ECC-1283: string arrays
+#--------------------------------------------------------------------
+sample=$ECCODES_SAMPLES_PATH/BUFR4.tmpl
+fBufrTmp1=temp1.${label}".bufr"
+fBufrTmp2=temp2.${label}".bufr"
+
+${tools_dir}/codes_bufr_filter -o $fBufrTmp1 - $sample <<EOF
+ set numberOfSubsets = 3;
+ set compressedData = 1;
+ set unexpandedDescriptors = { 1015 };
+ set stationOrSiteName = { "Black", "Rose", "Immortal" };
+ set pack=1;
+ write;
+EOF
+${tools_dir}/codes_bufr_filter -o $fBufrTmp2 - $sample <<EOF
+ set numberOfSubsets = 3;
+ set compressedData = 1;
+ set unexpandedDescriptors = { 1015 };
+ set stationOrSiteName = { "Black", "Rose", "Mortal" };
+ set pack=1;
+ write;
+EOF
+set +e
+${tools_dir}/bufr_compare $fBufrTmp1 $fBufrTmp2 >$fLog
+status=$?
+set -e
+[ $status -eq 1 ]
+grep -q "string \[stationOrSiteName\] 1 out of 3 different" $fLog
+
+${tools_dir}/bufr_compare -b stationOrSiteName $fBufrTmp1 $fBufrTmp2
+rm -f $fBufrTmp1 $fBufrTmp2
+
+# Comparing empty string with 'missing'
+${tools_dir}/codes_bufr_filter -o $fBufrTmp1 - $sample <<EOF
+ set numberOfSubsets = 3;
+ set compressedData = 1;
+ set unexpandedDescriptors = { 1015 };
+ set stationOrSiteName = { "", "y", "x" };
+ set pack=1;
+ write;
+EOF
+${tools_dir}/codes_bufr_filter -o $fBufrTmp2 - $sample <<EOF
+ set numberOfSubsets = 3;
+ set compressedData = 1;
+ set unexpandedDescriptors = { 1015 };
+ # stationOrSiteName not set so all entries 'missing'
+ set pack=1;
+ write;
+EOF
+export ECCODES_BUFR_MULTI_ELEMENT_CONSTANT_ARRAYS=1
+set +e
+${tools_dir}/bufr_compare $fBufrTmp1 $fBufrTmp2 >$fLog
+status=$?
+set -e
+[ $status -eq 1 ]
+grep -q "string \[stationOrSiteName\] 2 out of 3 different" $fLog
+
+${tools_dir}/bufr_compare -b stationOrSiteName $fBufrTmp1 $fBufrTmp2
+unset ECCODES_BUFR_MULTI_ELEMENT_CONSTANT_ARRAYS
+rm -f $fBufrTmp1 $fBufrTmp2
+
+
 # Clean up
 # -------------
 rm -f $fLog $fBufrTmp $fBufrInput1 $fBufrInput2 $fRules
